# mypy-boto3-license-manager<a id="mypy-boto3-license-manager"></a>

[![PyPI - mypy-boto3-license-manager](https://img.shields.io/pypi/v/mypy-boto3-license-manager.svg?color=blue)](https://pypi.org/project/mypy-boto3-license-manager)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-license-manager.svg?color=blue)](https://pypi.org/project/mypy-boto3-license-manager)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-license-manager?color=blue)](https://pypistats.org/packages/mypy-boto3-license-manager)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.LicenseManager 1.17.85](https://boto3.amazonaws.com/v1/documentation/api/1.17.85/reference/services/license-manager.html#LicenseManager)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.14.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-license-manager docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_license_manager/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-license-manager](#mypy-boto3-license-manager)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

## How to install<a id="how-to-install"></a>

Install `boto3-stubs` for `LicenseManager` service.

```bash
python -m pip install boto3-stubs[license-manager]
```

## Usage<a id="usage"></a>

### VSCode<a id="vscode"></a>

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[license-manager]` in your environment:
  `python -m pip install 'boto3-stubs[license-manager]'`

Both type checking and auto-complete should work for `LicenseManager` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm<a id="pycharm"></a>

- Install `boto-stubs[license-manager]` in your environment:
  `python -m pip install 'boto3-stubs[license-manager]'`

Both type checking and auto-complete should work for `LicenseManager` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

### Other IDEs<a id="other-ides"></a>

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

### mypy<a id="mypy"></a>

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[license-manager]` in your environment:
  `python -m pip install 'boto3-stubs[license-manager]'`
- Run `mypy` as usual

Type checking should work for `LicenseManager` service. No explicit type
annotations required, write your `boto3` code as usual.

### pyright<a id="pyright"></a>

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[license-manager]` in your environment:
  `python -m pip install 'boto3-stubs[license-manager]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `LicenseManager` service. No explicit type
annotations required, write your `boto3` code as usual.

## Explicit type annotations<a id="explicit-type-annotations"></a>

### Client annotations<a id="client-annotations"></a>

`LicenseManagerClient` provides annotations for
`boto3.client("license-manager")`.

```python
import boto3

from mypy_boto3_license_manager import LicenseManagerClient

client: LicenseManagerClient = boto3.client("license-manager")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: LicenseManagerClient = session.client("license-manager")
```

### Paginators annotations<a id="paginators-annotations"></a>

`mypy_boto3_license_manager.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_license_manager import LicenseManagerClient
from mypy_boto3_license_manager.paginator import (
    ListAssociationsForLicenseConfigurationPaginator,
    ListLicenseConfigurationsPaginator,
    ListLicenseSpecificationsForResourcePaginator,
    ListResourceInventoryPaginator,
    ListUsageForLicenseConfigurationPaginator,
)

client: LicenseManagerClient = boto3.client("license-manager")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_associations_for_license_configuration_paginator: ListAssociationsForLicenseConfigurationPaginator = client.get_paginator("list_associations_for_license_configuration")
list_license_configurations_paginator: ListLicenseConfigurationsPaginator = client.get_paginator("list_license_configurations")
list_license_specifications_for_resource_paginator: ListLicenseSpecificationsForResourcePaginator = client.get_paginator("list_license_specifications_for_resource")
list_resource_inventory_paginator: ListResourceInventoryPaginator = client.get_paginator("list_resource_inventory")
list_usage_for_license_configuration_paginator: ListUsageForLicenseConfigurationPaginator = client.get_paginator("list_usage_for_license_configuration")
```

### Literals<a id="literals"></a>

`mypy_boto3_license_manager.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from mypy_boto3_license_manager.literals import (
    AllowedOperationType,
    CheckoutTypeType,
    DigitalSignatureMethodType,
    EntitlementDataUnitType,
    EntitlementUnitType,
    GrantStatusType,
    InventoryFilterConditionType,
    LicenseConfigurationStatusType,
    LicenseCountingTypeType,
    LicenseDeletionStatusType,
    LicenseStatusType,
    ListAssociationsForLicenseConfigurationPaginatorName,
    ListLicenseConfigurationsPaginatorName,
    ListLicenseSpecificationsForResourcePaginatorName,
    ListResourceInventoryPaginatorName,
    ListUsageForLicenseConfigurationPaginatorName,
    ReceivedStatusType,
    RenewTypeType,
    ReportFrequencyTypeType,
    ReportTypeType,
    ResourceTypeType,
    TokenTypeType,
)

def check_value(value: AllowedOperationType) -> bool:
    ...
```

### Typed dictionaries<a id="typed-dictionaries"></a>

`mypy_boto3_license_manager.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_license_manager.type_defs import (
    AcceptGrantResponseTypeDef,
    AutomatedDiscoveryInformationTypeDef,
    BorrowConfigurationTypeDef,
    CheckoutBorrowLicenseResponseTypeDef,
    CheckoutLicenseResponseTypeDef,
    ConsumedLicenseSummaryTypeDef,
    ConsumptionConfigurationTypeDef,
    CreateGrantResponseTypeDef,
    CreateGrantVersionResponseTypeDef,
    CreateLicenseConfigurationResponseTypeDef,
    CreateLicenseManagerReportGeneratorResponseTypeDef,
    CreateLicenseResponseTypeDef,
    CreateLicenseVersionResponseTypeDef,
    CreateTokenResponseTypeDef,
    DatetimeRangeTypeDef,
    DeleteGrantResponseTypeDef,
    DeleteLicenseResponseTypeDef,
    EntitlementDataTypeDef,
    EntitlementTypeDef,
    EntitlementUsageTypeDef,
    ExtendLicenseConsumptionResponseTypeDef,
    FilterTypeDef,
    GetAccessTokenResponseTypeDef,
    GetGrantResponseTypeDef,
    GetLicenseConfigurationResponseTypeDef,
    GetLicenseManagerReportGeneratorResponseTypeDef,
    GetLicenseResponseTypeDef,
    GetLicenseUsageResponseTypeDef,
    GetServiceSettingsResponseTypeDef,
    GrantTypeDef,
    GrantedLicenseTypeDef,
    InventoryFilterTypeDef,
    IssuerDetailsTypeDef,
    IssuerTypeDef,
    LicenseConfigurationAssociationTypeDef,
    LicenseConfigurationTypeDef,
    LicenseConfigurationUsageTypeDef,
    LicenseOperationFailureTypeDef,
    LicenseSpecificationTypeDef,
    LicenseTypeDef,
    LicenseUsageTypeDef,
    ListAssociationsForLicenseConfigurationResponseTypeDef,
    ListDistributedGrantsResponseTypeDef,
    ListFailuresForLicenseConfigurationOperationsResponseTypeDef,
    ListLicenseConfigurationsResponseTypeDef,
    ListLicenseManagerReportGeneratorsResponseTypeDef,
    ListLicenseSpecificationsForResourceResponseTypeDef,
    ListLicenseVersionsResponseTypeDef,
    ListLicensesResponseTypeDef,
    ListReceivedGrantsResponseTypeDef,
    ListReceivedLicensesResponseTypeDef,
    ListResourceInventoryResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListTokensResponseTypeDef,
    ListUsageForLicenseConfigurationResponseTypeDef,
    ManagedResourceSummaryTypeDef,
    MetadataTypeDef,
    OrganizationConfigurationTypeDef,
    PaginatorConfigTypeDef,
    ProductInformationFilterTypeDef,
    ProductInformationTypeDef,
    ProvisionalConfigurationTypeDef,
    ReceivedMetadataTypeDef,
    RejectGrantResponseTypeDef,
    ReportContextTypeDef,
    ReportFrequencyTypeDef,
    ReportGeneratorTypeDef,
    ResourceInventoryTypeDef,
    S3LocationTypeDef,
    TagTypeDef,
    TokenDataTypeDef,
)

def get_structure() -> AcceptGrantResponseTypeDef:
    return {
      ...
    }
```

## Versioning<a id="versioning"></a>

`mypy-boto3-license-manager` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation<a id="documentation"></a>

All type annotations can be found in
[mypy-boto3-license-manager docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_license_manager/)

## Support and contributing<a id="support-and-contributing"></a>

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
